@@ -130,7 +130,7 @@ class KateIconBorder : public QWidget
     inline bool foldingMarkersOn()   const { return m_foldingMarkersOn;   }
     inline bool annotationBorderOn() const { return m_annotationBorderOn; }
 
-    enum BorderArea { None, LineNumbers, IconBorder, FoldingMarkers, AnnotationBorder };
+    enum BorderArea { None, LineNumbers, IconBorder, FoldingMarkers, AnnotationBorder, ModificationBorder };
     BorderArea positionToArea( const QPoint& ) const;
 
   Q_SIGNALS:
@@ -193,7 +193,6 @@ class KateIconBorder : public QWidget
     void showBlock();
 
   private:
-    QColor m_foldingHighlightColor;
     QString m_hoveredAnnotationText;
 
     void initializeFoldingColors();
